@@ -1,13 +1,15 @@
 """Module managing picking events."""
 
 import logging
+
 import numpy as np
 import vtk
 
 import pyvista
 from pyvista.utilities import try_callback
 
-class PickingHelper(object):
+
+class PickingHelper:
     """An internal class to hold picking related features."""
 
     picked_cells = None
@@ -20,7 +22,6 @@ class PickingHelper(object):
         """Get the pick position/area as x0, y0, x1, y1."""
         return self.renderer.get_pick_position()
 
-
     def enable_cell_picking(self, mesh=None, callback=None, through=True,
                             show=True, show_message=True, style='wireframe',
                             line_width=5, color='pink', font_size=18,
@@ -93,11 +94,11 @@ class PickingHelper(object):
 
         """
         if hasattr(self, 'notebook') and self.notebook:
-            raise AssertionError('Cell picking not available in notebook plotting')
+            raise TypeError('Cell picking not available in notebook plotting')
         if mesh is None:
             if not hasattr(self, 'mesh'):
-                raise Exception('Input a mesh into the Plotter class first or '
-                                'or set it in this function')
+                raise AttributeError('Input a mesh into the Plotter class first or '
+                                     'or set it in this function')
             mesh = self.mesh
 
         renderer = self.renderer # make sure to consistently use renderer
@@ -126,7 +127,6 @@ class PickingHelper(object):
             # TODO: Deactivate selection tool
             return
 
-
         def through_pick_call_back(picker, event_id):
             extract = vtk.vtkExtractGeometry()
             mesh.cell_arrays['orig_extract_id'] = np.arange(mesh.n_cells)
@@ -136,7 +136,6 @@ class PickingHelper(object):
             self.picked_cells = pyvista.wrap(extract.GetOutput())
             return end_pick_helper(picker, event_id)
 
-
         def visible_pick_call_back(picker, event_id):
             x0,y0,x1,y1 = renderer.get_pick_position()
             selector = vtk.vtkOpenGLHardwareSelector()
@@ -164,7 +163,6 @@ class PickingHelper(object):
                 self.picked_cells = picked
             return end_pick_helper(picker, event_id)
 
-
         area_picker = vtk.vtkRenderedAreaPicker()
         if through:
             area_picker.AddObserver(vtk.vtkCommand.EndPickEvent, through_pick_call_back)
@@ -197,7 +195,6 @@ class PickingHelper(object):
 
         return
 
-
     def enable_point_picking(self, callback=None, show_message=True,
                              font_size=18, color='pink', point_size=10,
                              use_mesh=False, show_point=True, tolerance=0.025,
@@ -246,7 +243,7 @@ class PickingHelper(object):
 
         """
         if hasattr(self, 'notebook') and self.notebook:
-            raise AssertionError('Point picking not available in notebook plotting')
+            raise TypeError('Point picking not available in notebook plotting')
 
         def _end_pick_event(picker, event):
             self.picked_point = np.array(picker.GetPickPosition())
@@ -278,7 +275,6 @@ class PickingHelper(object):
 
         return
 
-
     def enable_path_picking(self, callback=None, show_message=True,
                             font_size=18, color='pink', point_size=10,
                             line_width=5, show_path=True, tolerance=0.025,
@@ -330,17 +326,16 @@ class PickingHelper(object):
         kwargs.setdefault('pickable', False)
 
         def make_line_cells(n_points):
-            # cells = np.full((n_points-1, 3), 2, dtype=np.int)
-            # cells[:, 1] = np.arange(0, n_points-1, dtype=np.int)
-            # cells[:, 2] = np.arange(1, n_points, dtype=np.int)
-            cells = np.arange(0, n_points, dtype=np.int)
+            # cells = np.full((n_points-1, 3), 2, dtype=np.int_)
+            # cells[:, 1] = np.arange(0, n_points-1, dtype=np.int_)
+            # cells[:, 2] = np.arange(1, n_points, dtype=np.int_)
+            cells = np.arange(0, n_points, dtype=np.int_)
             cells = np.insert(cells, 0, n_points)
             return cells
 
         the_points = []
         the_ids = []
 
-
         def _the_callback(mesh, idx):
             if mesh is None:
                 return
@@ -370,7 +365,6 @@ class PickingHelper(object):
                 font_size=font_size, show_message=show_message,
                 show_point=False, tolerance=tolerance)
 
-
     def enable_geodesic_picking(self, callback=None, show_message=True,
                                 font_size=18, color='pink', point_size=10,
                                 line_width=5, tolerance=0.025, show_path=True,
@@ -464,8 +458,6 @@ class PickingHelper(object):
                 font_size=font_size, show_message=show_message,
                 tolerance=tolerance, show_point=False)
 
-
-
     def enable_horizon_picking(self, callback=None, normal=(0,0,1),
                                width=None, show_message=True,
                                font_size=18, color='pink', point_size=10,
@@ -549,7 +541,6 @@ class PickingHelper(object):
             point_size=point_size, line_width=line_width, show_path=show_path,
             **kwargs)
 
-
     def pick_click_position(self):
         """Get corresponding click location in the 3D plot."""
         if self.click_position is None:
@@ -558,7 +549,6 @@ class PickingHelper(object):
         picker.Pick(self.click_position[0], self.click_position[1], 0, self.renderer)
         return picker.GetPickPosition()
 
-
     def pick_mouse_position(self):
         """Get corresponding mouse location in the 3D plot."""
         if self.mouse_position is None:
@@ -567,7 +557,6 @@ class PickingHelper(object):
         picker.Pick(self.mouse_position[0], self.mouse_position[1], 0, self.renderer)
         return picker.GetPickPosition()
 
-
     def fly_to_mouse_position(self, focus=False):
         """Focus on last stored mouse position."""
         if self.mouse_position is None:
@@ -578,7 +567,6 @@ class PickingHelper(object):
         else:
             self.fly_to(click_point)
 
-
     def enable_fly_to_right_click(self, callback=None):
         """Set the camera to track right click positions.
 
@@ -587,6 +575,7 @@ class PickingHelper(object):
         3D space.
 
         """
+
         def _the_callback(*args):
             click_point = self.pick_mouse_position()
             self.fly_to(click_point)
