@@ -3,12 +3,11 @@
 import logging
 import os
 import re
-import scooby
 import sys
-import warnings
 
-import vtk
 import numpy as np
+import scooby
+import vtk
 
 import pyvista
 
@@ -130,7 +129,6 @@ class GPUInfo():
         """Instantiate a container for the GPU information."""
         self._gpu_info = get_gpu_info()
 
-
     @property
     def renderer(self):
         """GPU renderer name."""
@@ -141,7 +139,6 @@ class GPUInfo():
             raise RuntimeError("Unable to parse GPU information for the renderer.")
         return renderer.strip()
 
-
     @property
     def version(self):
         """GPU renderer version."""
@@ -152,7 +149,6 @@ class GPUInfo():
             raise RuntimeError("Unable to parse GPU information for the version.")
         return version.strip()
 
-
     @property
     def vendor(self):
         """GPU renderer vendor."""
@@ -163,7 +159,6 @@ class GPUInfo():
             raise RuntimeError("Unable to parse GPU information for the vendor.")
         return vendor.strip()
 
-
     def get_info(self):
         """All GPU information as tuple pairs."""
         return (("GPU Vendor", self.vendor),
@@ -171,7 +166,6 @@ class GPUInfo():
                 ("GPU Version", self.version),
                )
 
-
     def _repr_html_(self):
         """HTML table representation."""
         fmt = "<table>"
@@ -181,7 +175,6 @@ class GPUInfo():
         fmt += "</table>"
         return fmt
 
-
     def __repr__(self):
         """Representation method."""
         content = "\n"
@@ -191,7 +184,6 @@ class GPUInfo():
         return content
 
 
-
 class Report(scooby.Report):
     """A class for custom scooby.Report."""
 
@@ -221,11 +213,12 @@ class Report(scooby.Report):
 
         """
         # Mandatory packages.
-        core = ['pyvista', 'vtk', 'numpy', 'imageio', 'appdirs', 'scooby']
+        core = ['pyvista', 'vtk', 'numpy', 'imageio', 'appdirs', 'scooby',
+                'meshio']
 
         # Optional packages.
-        optional = ['matplotlib', 'PyQt5', 'IPython', 'colorcet',
-                    'cmocean', 'panel', 'scipy']
+        optional = ['matplotlib', 'pyvistaqt', 'PyQt5', 'IPython', 'colorcet',
+                    'cmocean', 'panel', 'scipy', 'itkwidgets', 'tqdm']
 
         # Information about the GPU - bare except in case there is a rendering
         # bug that the user is trying to report.
@@ -234,6 +227,8 @@ class Report(scooby.Report):
                 extra_meta = [(t[1], t[0]) for t in GPUInfo().get_info()]
             except:
                 extra_meta = ("GPU Details", "error")
+        else:
+            extra_meta = ("GPU Details", "None")
 
         scooby.Report.__init__(self, additional=additional, core=core,
                                optional=optional, ncol=ncol,
